@@ -5,18 +5,9 @@ use warnings;
 package Acme::Marvel::CinematicUniverse::Character;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
-use Class::Tiny qw(
-	real_name
-	hero_name
-	intelligence
-	strength
-	speed
-	durability
-	energy_projection
-	fighting_ability
-);
+use Acme::Marvel::CinematicUniverse::Mite qw( param -bool );
 
 use overload (
 	q[bool]  => sub { !!1 },
@@ -25,6 +16,15 @@ use overload (
 	fallback => !!1,
 );
 
+param real_name          => ( isa => 'Str' );
+param hero_name          => ( isa => 'Str' );
+param intelligence       => ( isa => 'PositiveInt' );
+param strength           => ( isa => 'PositiveInt' );
+param speed              => ( isa => 'PositiveInt' );
+param durability         => ( isa => 'PositiveInt' );
+param energy_projection  => ( isa => 'PositiveInt' );
+param fighting_ability   => ( isa => 'PositiveInt' );
+
 sub power {
 	my $self = shift;
 	my $sum;
@@ -37,7 +37,7 @@ sub power {
 		fighting_ability
 	);
 	return $sum;
-}
+} #/ sub power
 
 1;
 
@@ -133,4 +133,3 @@ the same terms as the Perl 5 programming language system itself.
 THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
